@@ -6,31 +6,13 @@
 #
 """"""
 import os
-import json
+from pure_attention.backbone_bert.package import BertConfig, BertOutput
 import torch
 from torch import nn
-from bert.bert_layer import BertLayer
-from bert.bert_layer import BertEmbeddings
+from pure_attention.backbone_bert.bert_layer import BertLayer, BertEmbeddings
 from pure_attention.common.layers import LayerNorm as BertLayerNorm
 
 
-class BertConfig:
-    def __init__(self, vocab_size_or_config_json_file):
-        """
-        定制化的 config，__getattr__ 处进行判断
-        """
-        with open(vocab_size_or_config_json_file, "r", encoding='utf-8') as reader:
-            json_config = json.loads(reader.read())
-        for key, value in json_config.items():
-            self.__dict__[key] = value
-            print(f"{key}:{value}({type(value)})")
-
-    def __getattr__(self, key):
-        if key in self.__dict__:
-            return self.__dict__[key]
-        return None
-
-
 class BertEncoder(nn.Module):
     def __init__(self, config):
         super(BertEncoder, self).__init__()
@@ -94,6 +76,7 @@ class BertModel(nn.Module):
 
         self.init_weights()
         self.from_pretrained(os.path.join(os.path.join(config_path, "pytorch_model.bin")))
+        self.eval()
 
     def init_weights(self):
         self.apply(self._init_weights)
@@ -190,24 +173,7 @@ class BertModel(nn.Module):
         sequence_output = encoder_outputs[0]
         pooled_output = self.pooler(sequence_output)
 
-        # add hidden_states and attentions if they are here,
-        outputs = (sequence_output, pooled_output,) + encoder_outputs[1:]
+        outputs = BertOutput(last_hidden_state=sequence_output, pooler_output=pooled_output,
+                             attentions=encoder_outputs[1:])
 
-        # sequence_output, pooled_output, (hidden_states), (attentions)
         return outputs
-
-
-if __name__ == "__main__":
-    """
-from common.nlp.tokenization import Tokenizer
-from common.bert.bert_model import BertModel
-tokenizer = Tokenizer("/data1/lifeiyang/data/pretrain_modal/chinese-roberta-wwm-ext/vocab.txt")
-bert = BertModel("/data1/lifeiyang/data/pretrain_modal/chinese-roberta-wwm-ext")
-
-sentence = "123"
-tokens_ids, segments_ids = tokenizer.encode("123", max_len=64)
-
-_ = bert(tokens_ids,token_type_ids=segments_ids)[1]
-print("pass")
-
-    """
